@@ -24,7 +24,9 @@ from peek_platform.file_config.PeekFileConfigFrontendDirMixin import (
 from peek_platform.file_config.PeekFileConfigHttpServerMixin import (
     PeekFileConfigHttpMixin,
 )
-from peek_platform.file_config.PeekFileConfigOsMixin import PeekFileConfigOsMixin
+from peek_platform.file_config.PeekFileConfigOsMixin import (
+    PeekFileConfigOsMixin,
+)
 from peek_platform.file_config.PeekFileConfigPeekServerClientMixin import (
     PeekFileConfigPeekServerClientMixin,
 )
